@@ -1,4 +1,4 @@
-package URI::Query::FromHash 0.001;
+package URI::Query::FromHash 0.002;
 
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ sub hash2query(+%) {
 
     utf8::encode $q;
 
-    $q =~ s|([^\Q;/?:@&=+,$[]%-_.!~*'()\EA-Za-z0-9])|@escapes{ split //, $1 }|eg;
+    $q =~ s|([^\Q;/?:@&=+,\$\[\]%-_.!~*'()\EA-Za-z0-9])|@escapes{ split //, $1 }|eg;
 
     $q;
 }
